Skip to contents

Bind hyperspectral SpatRasters along the spectral axis

Usage

hsi_bind_layers(x, filename = "", overwrite = FALSE, ...)

Arguments

x

List of SpatRaster objects with hyperspectral data. All elements must share the same spatial resolution and spatial extent (pixel to pixel coverage).

filename

Character. Output filename. Default "" keeps result in memory.

overwrite

Logical. Overwrite existing file. Default FALSE.

...

Additional arguments passed to terra::merge().

Value

A SpatRaster with all inputs bound along the spectral axis in the order provided.