Calculate Relative Absorption Band Depth (RABD)
Usage
hsi_calc_rabd(
x,
continuum_edges,
absorption_band,
index_type,
index_name = NULL,
filename = "",
overwrite = FALSE,
...
)Arguments
- x
A
SpatRasterwith hyperspectral data.- continuum_edges
Numeric vector of length 2. Continuum anchor wavelengths in nm.
- absorption_band
Numeric vector. Wavelength(s) in nm to search for trough (absorption feature). Single value for
"strict"type.- index_type
Character. Type of RABD index. One of:
"max"Flexibly find the lowest reflectance within the trough range.
"strict"Use a specific wavelength as the trough.
"mid"Use the midpoint between the min and max trough wavelength.
- index_name
Character. Name for the output layer. Default
NULL.- filename
Character. Output filename. Default
""keeps result in memory.- overwrite
Logical. Overwrite existing file. Default
FALSE.- ...
Additional arguments passed to
terra::writeRaster().
Value
A SpatRaster with RABD values.
See also
Other HSI Transformations:
hsi_apply_mnf(),
hsi_calc_difference(),
hsi_calc_mnf(),
hsi_calc_ndi(),
hsi_calc_raba(),
hsi_calc_ratio(),
hsi_calc_rcv(),
hsi_calc_reflectance(),
hsi_calc_remp(),
hsi_calc_rmean(),
hsi_calc_rmedian(),
hsi_calc_rsd(),
hsi_calc_stretch(),
hsi_destripe(),
hsi_remove_continuum(),
hsi_smooth_median(),
hsi_smooth_savgol(),
hsi_tiled(),
hsi_write_scaled()
Examples
if (FALSE) { # \dontrun{
x <- terra::rast("REFLECTANCE_testdata.tif")
x_rabd <- hsi_calc_rabd(
x,
continuum_edges = c(590, 730),
absorption_band = 660:680,
index_type = "max"
)
x_rabd <- hsi_calc_rabd(
x,
continuum_edges = c(590, 730),
absorption_band = 673,
index_type = "strict",
index_name = "rabd673",
filename = "output_rabd.tif",
overwrite = TRUE
)
} # }