Create spatial calibration from known resolution
Source:R/hsi_calibration_direct.R
hsi_calibration_direct.RdCreate a spatial calibration when the pixel size is known directly. This is the simplest calibration path. The value is stored internally in micrometers per pixel.
See also
Other HSI Calibration:
hsi_calibration_from_dims(),
hsi_calibration_from_scale(),
hsi_drop_crs(),
hsi_pixels_to_units(),
hsi_set_extent()